netapp_ontap.models.vscan_on_demand_policy API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vscan_on_demand_policy`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VscanOnDemandPolicySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VscanOnDemandPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `log_path: str GET POST PATCH`

    The path from the Vserver root where the task report is created.

    Example: /vol0/report_dir

  `name: str GET POST`

    On-Demand task name

    Example: task-1

  `scan_paths: List[str] GET POST PATCH`

    List of paths that need to be scanned.

    Example: ["/vol1/","/vol2/cifs/"]

  `schedule: Schedule GET POST PATCH`

    The schedule field of the vscan_on_demand_policy.

  `scope: VscanOnDemandScope GET POST PATCH`

    The scope field of the vscan_on_demand_policy.